aboutsummaryrefslogtreecommitdiffstats
path: root/wiretap
diff options
context:
space:
mode:
authorGuy Harris <guy@alum.mit.edu>2004-10-29 02:40:01 +0000
committerGuy Harris <guy@alum.mit.edu>2004-10-29 02:40:01 +0000
commit1e6a5d408c8c861df1a5433c3a5efdd56b417e2f (patch)
tree7f2da4cf9cfd81ba9030fc818faa4a000bdcab43 /wiretap
parent898c26a82fc175d34622d3a6100af6077c2c6c07 (diff)
As Sam Leffler notes, the radiotap header isn't BSD-only, it's also used
by his madwifi Atheros driver on Linux; rename WTAP_ENCAP_IEEE_802_11_WLAN_BSD to WTAP_ENCAP_IEEE_802_11_WLAN_RADIOTAP, and change its text name from "ieee-802-11-bsd" to "ieee-802-11-radiotap". svn path=/trunk/; revision=12429
Diffstat (limited to 'wiretap')
-rw-r--r--wiretap/libpcap.c6
-rw-r--r--wiretap/wtap.c4
-rw-r--r--wiretap/wtap.h2
3 files changed, 6 insertions, 6 deletions
diff --git a/wiretap/wtap.c b/wiretap/wtap.c
index a58e93fc32..8b0423eb09 100644
--- a/wiretap/wtap.c
+++ b/wiretap/wtap.c
@@ -129,8 +129,8 @@ static const struct encap_type_info {
/* WTAP_ENCAP_IEEE_802_11_WITH_RADIO */
{ "IEEE 802.11 Wireless LAN with radio information", "ieee-802-11-radio" },
- /* WTAP_ENCAP_IEEE_802_11_WLAN_BSD */
- { "IEEE 802.11 plus BSD WLAN header", "ieee-802-11-bsd" },
+ /* WTAP_ENCAP_IEEE_802_11_WLAN_RADIOTAP */
+ { "IEEE 802.11 plus radiotap WLAN header", "ieee-802-11-radiotap" },
/* WTAP_ENCAP_IEEE_802_11_WLAN_AVS */
{ "IEEE 802.11 plus AVS WLAN header", "ieee-802-11-avs" },
diff --git a/wiretap/wtap.h b/wiretap/wtap.h
index d624df981f..c2157c717d 100644
--- a/wiretap/wtap.h
+++ b/wiretap/wtap.h
@@ -112,7 +112,7 @@
#define WTAP_ENCAP_IEEE_802_11 20
#define WTAP_ENCAP_PRISM_HEADER 21
#define WTAP_ENCAP_IEEE_802_11_WITH_RADIO 22
-#define WTAP_ENCAP_IEEE_802_11_WLAN_BSD 23
+#define WTAP_ENCAP_IEEE_802_11_WLAN_RADIOTAP 23
#define WTAP_ENCAP_IEEE_802_11_WLAN_AVS 24
#define WTAP_ENCAP_SLL 25
#define WTAP_ENCAP_FRELAY 26
diff --git a/wiretap/libpcap.c b/wiretap/libpcap.c
index e58821a82a..d36f7f2f1d 100644
--- a/wiretap/libpcap.c
+++ b/wiretap/libpcap.c
@@ -289,7 +289,7 @@ static const struct {
{ 121, WTAP_ENCAP_HHDLC }, /* HiPath HDLC */
{ 122, WTAP_ENCAP_IP_OVER_FC }, /* RFC 2625 IP-over-FC */
{ 123, WTAP_ENCAP_ATM_PDUS }, /* SunATM */
- { 127, WTAP_ENCAP_IEEE_802_11_WLAN_BSD }, /* 802.11 plus BSD WLAN header */
+ { 127, WTAP_ENCAP_IEEE_802_11_WLAN_RADIOTAP }, /* 802.11 plus radiotap WLAN header */
{ 128, WTAP_ENCAP_TZSP }, /* Tazmen Sniffer Protocol */
{ 129, WTAP_ENCAP_ARCNET_LINUX },
@@ -1152,7 +1152,7 @@ static gboolean libpcap_read(wtap *wth, int *err, gchar **err_info,
case WTAP_ENCAP_IEEE_802_11:
case WTAP_ENCAP_PRISM_HEADER:
- case WTAP_ENCAP_IEEE_802_11_WLAN_BSD:
+ case WTAP_ENCAP_IEEE_802_11_WLAN_RADIOTAP:
case WTAP_ENCAP_IEEE_802_11_WLAN_AVS:
/*
* We don't know whether there's an FCS in this frame or not.
@@ -1266,7 +1266,7 @@ libpcap_seek_read(wtap *wth, long seek_off,
case WTAP_ENCAP_IEEE_802_11:
case WTAP_ENCAP_PRISM_HEADER:
- case WTAP_ENCAP_IEEE_802_11_WLAN_BSD:
+ case WTAP_ENCAP_IEEE_802_11_WLAN_RADIOTAP:
case WTAP_ENCAP_IEEE_802_11_WLAN_AVS:
/*
* We don't know whether there's an FCS in this frame or not.